CVS commit: src/sys/arch/mips/ingenic

2015-03-09 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Mon Mar  9 13:22:37 UTC 2015

Modified Files:
src/sys/arch/mips/ingenic: ingenic_regs.h

Log Message:
moar registers


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/mips/ingenic/ingenic_regs.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/mips/ingenic/ingenic_regs.h
diff -u src/sys/arch/mips/ingenic/ingenic_regs.h:1.7 src/sys/arch/mips/ingenic/ingenic_regs.h:1.8
--- src/sys/arch/mips/ingenic/ingenic_regs.h:1.7	Sat Mar  7 15:36:16 2015
+++ src/sys/arch/mips/ingenic/ingenic_regs.h	Mon Mar  9 13:22:37 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ingenic_regs.h,v 1.7 2015/03/07 15:36:16 macallan Exp $ */
+/*	$NetBSD: ingenic_regs.h,v 1.8 2015/03/09 13:22:37 macallan Exp $ */
 
 /*-
  * Copyright (c) 2014 Michael Lorenz
@@ -221,7 +221,7 @@ MFC0(uint32_t r, uint32_t s)
 	#define PCR_TXPREEMPH	0x0080	/* HS transm. pre-emphasis */
 	#define PCR_TXHSXVTUNE1	0x0060	/* dp/dm voltage adj. */
 	#define PCR_TXVREFTUNE1	0x0017	/* HS DC voltage adj. */
-	#define PCR_TXRISETUNE1	0x0001	/* risa/fall wave adj. */
+	#define PCR_TXRISETUNE1	0x0001	/* rise/fall wave adj. */
 
 #define JZ_UHCCDR	0x106c	/* UHC Clock Divider Register */
 #define JZ_SPCR0	0x10b8	/* SRAM Power Control Registers */
@@ -255,5 +255,14 @@ MFC0(uint32_t r, uint32_t s)
 	#define	DMMAP_BASE	0xff00	/* base PADDR of memory chunk */
 	#define DMMAP_MASK	0x00ff	/* mask which bits of PADDR are
 		 * constant */
+/* USB controllers */
+#define JZ_EHCI_BASE	0x1349
+#define JZ_OHCI_BASE	0x134a
+#define JZ_DWC2_BASE	0x1350
+
+/* Ethernet */
+#define JZ_DME_BASE	0x1600
+#define JZ_DME_IO	JZ_DME_BASE
+#define JZ_DME_ADDR	(JZ_DME_BASE + 2)
 
 #endif /* INGENIC_REGS_H */



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Mar  9 13:55:49 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: usbhist.h

Log Message:
Add USBHIST_LOGM which uses masks to control logging


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.1.2.1 src/sys/dev/usb/usbhist.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbhist.h
diff -u src/sys/dev/usb/usbhist.h:1.1 src/sys/dev/usb/usbhist.h:1.1.2.1
--- src/sys/dev/usb/usbhist.h:1.1	Fri Sep 12 16:40:38 2014
+++ src/sys/dev/usb/usbhist.h	Mon Mar  9 13:55:49 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: usbhist.h,v 1.1 2014/09/12 16:40:38 skrll Exp $	*/
+/*	$NetBSD: usbhist.h,v 1.1.2.1 2015/03/09 13:55:49 skrll Exp $	*/
 
 /*
  * Copyright (c) 2012 Matthew R. Green
@@ -57,6 +57,11 @@ extern int usbdebug;
 		KERNHIST_LOG(usbhist,FMT,A,B,C,D);		\
 	}			\
 } while (0)
+#define USBHIST_LOGM(NAME,N,FMT,A,B,C,D)	do {		\
+	if ((NAME)  (N)) {	\
+		KERNHIST_LOG(usbhist,FMT,A,B,C,D);		\
+	}			\
+} while (0)
 #define USBHIST_LOG(NAME,FMT,A,B,C,D)	USBHIST_LOGN(NAME,1,FMT,A,B,C,D)
 #define USBHIST_CALLED(NAME)			do {		\
 	if ((NAME) != 0) {	\



CVS commit: src/distrib/sets/lists/modules

2015-03-09 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Mon Mar  9 12:32:11 UTC 2015

Modified Files:
src/distrib/sets/lists/modules: md.amd64 mi

Log Message:
Add missing entries for dtrace modules to set lists.


To generate a diff of this commit:
cvs rdiff -u -r1.54 -r1.55 src/distrib/sets/lists/modules/md.amd64
cvs rdiff -u -r1.72 -r1.73 src/distrib/sets/lists/modules/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/modules/md.amd64
diff -u src/distrib/sets/lists/modules/md.amd64:1.54 src/distrib/sets/lists/modules/md.amd64:1.55
--- src/distrib/sets/lists/modules/md.amd64:1.54	Sun Mar  8 17:13:22 2015
+++ src/distrib/sets/lists/modules/md.amd64	Mon Mar  9 12:32:11 2015
@@ -1,4 +1,4 @@
-# $NetBSD: md.amd64,v 1.54 2015/03/08 17:13:22 christos Exp $
+# $NetBSD: md.amd64,v 1.55 2015/03/09 12:32:11 riastradh Exp $
 #
 # NOTE that there are two sets of files here:
 # @MODULEDIR@ and amd64-xen
@@ -67,6 +67,10 @@
 ./@MODULEDIR@/drmkms_linux/drmkms_linux.kmod	base-kernel-modules	kmod
 ./@MODULEDIR@/drmkms_pci			base-kernel-modules	kmod
 ./@MODULEDIR@/drmkms_pci/drmkms_pci.kmod	base-kernel-modules	kmod
+./@MODULEDIR@/dtrace_syscall_linux32		base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall_linux32/dtrace_syscall_linux32.kmod	base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall_netbsd32		base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall_netbsd32/dtrace_syscall_netbsd32.kmod	base-kernel-modules	kmod,dtrace
 ./@MODULEDIR@/emdtvbase-kernel-modules	kmod
 ./@MODULEDIR@/emdtv/emdtv.kmod			base-kernel-modules	kmod
 ./@MODULEDIR@/estbase-kernel-modules	kmod
@@ -270,6 +274,8 @@
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace/dtrace.kmod		base-kernel-modules	kmod,dtrace,compatmodules
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace_fbt			base-kernel-modules	kmod,dtrace,compatmodules
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace_fbt/dtrace_fbt.kmod	base-kernel-modules	kmod,dtrace,compatmodules
+./stand/amd64-xen/@OSRELEASE@/modules/dtrace_lockstat			base-kernel-modules	kmod,dtrace,compatmodules
+./stand/amd64-xen/@OSRELEASE@/modules/dtrace_lockstat/dtrace_lockstat.kmod	base-kernel-modules	kmod,dtrace,compatmodules
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace_profilebase-kernel-modules	kmod,dtrace,compatmodules
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace_profile/dtrace_profile.kmod	base-kernel-modules	kmod,dtrace,compatmodules
 ./stand/amd64-xen/@OSRELEASE@/modules/dtrace_sdt			base-kernel-modules	kmod,dtrace,compatmodules

Index: src/distrib/sets/lists/modules/mi
diff -u src/distrib/sets/lists/modules/mi:1.72 src/distrib/sets/lists/modules/mi:1.73
--- src/distrib/sets/lists/modules/mi:1.72	Sun Mar  8 22:47:22 2015
+++ src/distrib/sets/lists/modules/mi	Mon Mar  9 12:32:11 2015
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.72 2015/03/08 22:47:22 christos Exp $
+# $NetBSD: mi,v 1.73 2015/03/09 12:32:11 riastradh Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -66,6 +66,10 @@
 ./@MODULEDIR@/dtrace_profile/dtrace_profile.kmod	base-kernel-modules	kmod,dtrace
 ./@MODULEDIR@/dtrace_sdtbase-kernel-modules	kmod,dtrace
 ./@MODULEDIR@/dtrace_sdt/dtrace_sdt.kmod		base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscallbase-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall/dtrace_syscall.kmod	base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall_linux			base-kernel-modules	kmod,dtrace
+./@MODULEDIR@/dtrace_syscall_linux/dtrace_syscall_linux.kmod	base-kernel-modules	kmod,dtrace
 ./@MODULEDIR@/dtvbase-kernel-modules	kmod
 ./@MODULEDIR@/dtv/dtv.kmod			base-kernel-modules	kmod
 ./@MODULEDIR@/dtv_mathbase-kernel-modules	kmod



CVS commit: src/sys/arch/mips/ingenic

2015-03-09 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Mon Mar  9 13:24:21 UTC 2015

Modified Files:
src/sys/arch/mips/ingenic: apbus.c

Log Message:
moar devices


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/mips/ingenic/apbus.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/mips/ingenic/apbus.c
diff -u src/sys/arch/mips/ingenic/apbus.c:1.6 src/sys/arch/mips/ingenic/apbus.c:1.7
--- src/sys/arch/mips/ingenic/apbus.c:1.6	Sat Dec 27 17:22:15 2014
+++ src/sys/arch/mips/ingenic/apbus.c	Mon Mar  9 13:24:21 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: apbus.c,v 1.6 2014/12/27 17:22:15 macallan Exp $ */
+/*	$NetBSD: apbus.c,v 1.7 2015/03/09 13:24:21 macallan Exp $ */
 
 /*-
  * Copyright (c) 2014 Michael Lorenz
@@ -29,7 +29,7 @@
 /* catch-all for on-chip peripherals */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: apbus.c,v 1.6 2014/12/27 17:22:15 macallan Exp $);
+__KERNEL_RCSID(0, $NetBSD: apbus.c,v 1.7 2015/03/09 13:24:21 macallan Exp $);
 
 #include locators.h
 #define	_MIPS_BUS_DMA_PRIVATE
@@ -64,6 +64,9 @@ struct mips_bus_dma_tag	apbus_dmat = {
 
 static const char *apbus_devs[] = {
 	dwctwo,
+	ohci,
+	ehci,
+	dme,
 	jzgpio,
 	jzfb,
 	NULL



CVS commit: src/sys/arch/mips/ingenic

2015-03-09 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Mon Mar  9 13:23:57 UTC 2015

Modified Files:
src/sys/arch/mips/ingenic: ingenic_dwctwo.c

Log Message:
magic number reduction


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/arch/mips/ingenic/ingenic_dwctwo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/mips/ingenic/ingenic_dwctwo.c
diff -u src/sys/arch/mips/ingenic/ingenic_dwctwo.c:1.5 src/sys/arch/mips/ingenic/ingenic_dwctwo.c:1.6
--- src/sys/arch/mips/ingenic/ingenic_dwctwo.c:1.5	Sat Dec 27 17:22:15 2014
+++ src/sys/arch/mips/ingenic/ingenic_dwctwo.c	Mon Mar  9 13:23:57 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ingenic_dwctwo.c,v 1.5 2014/12/27 17:22:15 macallan Exp $ */
+/*	$NetBSD: ingenic_dwctwo.c,v 1.6 2015/03/09 13:23:57 macallan Exp $ */
 
 /*-
  * Copyright (c) 2014 Michael Lorenz
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ingenic_dwctwo.c,v 1.5 2014/12/27 17:22:15 macallan Exp $);
+__KERNEL_RCSID(0, $NetBSD: ingenic_dwctwo.c,v 1.6 2015/03/09 13:23:57 macallan Exp $);
 
 /*
  * adapted from bcm2835_dwctwo.c
@@ -124,7 +124,7 @@ ingenic_dwc2_attach(device_t parent, dev
 	sc-sc_dwc2.sc_params = ingenic_dwc2_params;
 
 	if (aa-aa_addr == 0)
-		aa-aa_addr = 0x1350;
+		aa-aa_addr = JZ_DWC2_BASE;
 
 	error = bus_space_map(aa-aa_bst, aa-aa_addr, 0x2, 0,
 	sc-sc_dwc2.sc_ioh);



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Mar  9 14:24:17 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: motg.c

Log Message:
Remove a header that isn't needed.


To generate a diff of this commit:
cvs rdiff -u -r1.12.2.14 -r1.12.2.15 src/sys/dev/usb/motg.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/motg.c
diff -u src/sys/dev/usb/motg.c:1.12.2.14 src/sys/dev/usb/motg.c:1.12.2.15
--- src/sys/dev/usb/motg.c:1.12.2.14	Sun Mar  8 15:31:18 2015
+++ src/sys/dev/usb/motg.c	Mon Mar  9 14:24:17 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: motg.c,v 1.12.2.14 2015/03/08 15:31:18 skrll Exp $	*/
+/*	$NetBSD: motg.c,v 1.12.2.15 2015/03/09 14:24:17 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2011, 2012, 2014 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
 #include opt_motg.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: motg.c,v 1.12.2.14 2015/03/08 15:31:18 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: motg.c,v 1.12.2.15 2015/03/09 14:24:17 skrll Exp $);
 
 #include sys/param.h
 
@@ -62,7 +62,6 @@ __KERNEL_RCSID(0, $NetBSD: motg.c,v 1.1
 #include dev/usb/usbdi.h
 #include dev/usb/usbdivar.h
 #include dev/usb/usb_mem.h
-#include dev/usb/usb_quirks.h
 
 #ifdef MOTG_ALLWINNER
 #include arch/arm/allwinner/awin_otgreg.h



CVS commit: [nick-nhusb] src/sys

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Mar  9 14:26:31 UTC 2015

Modified Files:
src/sys/arch/arm/omap [nick-nhusb]: tiotg.c
src/sys/dev/usb [nick-nhusb]: motg.c

Log Message:
Convert to USBHIST


To generate a diff of this commit:
cvs rdiff -u -r1.2.8.2 -r1.2.8.3 src/sys/arch/arm/omap/tiotg.c
cvs rdiff -u -r1.12.2.15 -r1.12.2.16 src/sys/dev/usb/motg.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/omap/tiotg.c
diff -u src/sys/arch/arm/omap/tiotg.c:1.2.8.2 src/sys/arch/arm/omap/tiotg.c:1.2.8.3
--- src/sys/arch/arm/omap/tiotg.c:1.2.8.2	Wed Dec  3 12:52:05 2014
+++ src/sys/arch/arm/omap/tiotg.c	Mon Mar  9 14:26:31 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: tiotg.c,v 1.2.8.2 2014/12/03 12:52:05 skrll Exp $ */
+/* $NetBSD: tiotg.c,v 1.2.8.3 2015/03/09 14:26:31 skrll Exp $ */
 /*
  * Copyright (c) 2013 Manuel Bouyer.  All rights reserved.
  *
@@ -24,7 +24,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: tiotg.c,v 1.2.8.2 2014/12/03 12:52:05 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: tiotg.c,v 1.2.8.3 2015/03/09 14:26:31 skrll Exp $);
 
 #include opt_omap.h
 #include locators.h
@@ -56,14 +56,19 @@ __KERNEL_RCSID(0, $NetBSD: tiotg.c,v 1.
 #include dev/usb/usb_mem.h
 #include dev/usb/motgreg.h
 #include dev/usb/motgvar.h
+#include dev/usb/usbhist.h
 
-#define MOTG_DEBUG
-#ifdef MOTG_DEBUG
-extern int motgdebug;
-#define DPRINTF(x) if (motgdebug) printf x
+#ifdef USB_DEBUG
+#ifndef MOTG_DEBUG
+#define motgdebug 0
 #else
-#define DPRINTF(x)
-#endif
+extern int motgdebug;
+#endif /* MOTG_DEBUG */
+#endif /* USB_DEBUG */
+
+#define	DPRINTF(FMT,A,B,C,D)	USBHIST_LOGN(motgdebug,1,FMT,A,B,C,D)
+#define	MOTGHIST_FUNC()		USBHIST_FUNC()
+#define	MOTGHIST_CALLED(name)	USBHIST_CALLED(motgdebug)
 
 struct tiotg_softc {
 	device_t		sc_dev;
@@ -283,6 +288,7 @@ ti_motg_attach(device_t parent, device_t
 	const char *mode;
 	u_int state;
 #endif
+	MOTGHIST_FUNC(); MOTGHIST_CALLED();
 
 	sc-sc_motg.sc_dev = self;
 	sc-sc_ctrliot = aa-aa_iot;
@@ -317,14 +323,14 @@ ti_motg_attach(device_t parent, device_t
 	}
 	/* turn clock on */
 	sitara_cm_reg_read_4(tiotg_port_control[sc-sc_ctrlport].scm_reg, val);
-	DPRINTF(( power val 0x%x, val));
+	DPRINTF(power val 0x%x, val, 0, 0, 0);
 	/* Enable power */
 	val = ~(OMAP2SCM_USB_CTLx_OTGPHY_PWD | OMAP2SCM_USB_CTLx_CMPHY_PWD);
 	/* enable vbus detect and session end */
 	val |= (OMAP2SCM_USB_CTLx_VBUSDET | OMAP2SCM_USB_CTLx_SESSIONEND);
 	sitara_cm_reg_write_4(tiotg_port_control[sc-sc_ctrlport].scm_reg, val);
 	sitara_cm_reg_read_4(tiotg_port_control[sc-sc_ctrlport].scm_reg, val);
-	DPRINTF((now val 0x%x , val));
+	DPRINTF(now val 0x%x, val, 0, 0, 0);
 #endif
 	/* XXX configure mode */
 	if (sc-sc_ctrlport == 0)
@@ -380,12 +386,13 @@ ti_motg_intr(void *v)
 	int rv = 0;
 	int i;
 
+	MOTGHIST_FUNC(); MOTGHIST_CALLED();
+
 	mutex_spin_enter(sc-sc_motg.sc_intr_lock);
 	stat = TIOTG_USBC_READ4(sc, USBCTRL_STAT);
 	stat0 = TIOTG_USBC_READ4(sc, USBCTRL_IRQ_STAT0);
 	stat1 = TIOTG_USBC_READ4(sc, USBCTRL_IRQ_STAT1);
-	DPRINTF((USB %d 0x%x 0x%x stat %d\n,
-	sc-sc_ctrlport, stat0, stat1, stat));
+	DPRINTF(USB %d 0x%x 0x%x stat %d, sc-sc_ctrlport, stat0, stat1, stat);
 	/* try to deal with vbus errors */
 	if (stat1  MUSB2_MASK_IVBUSERR ) {
 		stat1 = ~MUSB2_MASK_IVBUSERR;

Index: src/sys/dev/usb/motg.c
diff -u src/sys/dev/usb/motg.c:1.12.2.15 src/sys/dev/usb/motg.c:1.12.2.16
--- src/sys/dev/usb/motg.c:1.12.2.15	Mon Mar  9 14:24:17 2015
+++ src/sys/dev/usb/motg.c	Mon Mar  9 14:26:31 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: motg.c,v 1.12.2.15 2015/03/09 14:24:17 skrll Exp $	*/
+/*	$NetBSD: motg.c,v 1.12.2.16 2015/03/09 14:26:31 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2011, 2012, 2014 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
 #include opt_motg.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: motg.c,v 1.12.2.15 2015/03/09 14:24:17 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: motg.c,v 1.12.2.16 2015/03/09 14:26:31 skrll Exp $);
 
 #include sys/param.h
 
@@ -54,6 +54,7 @@ __KERNEL_RCSID(0, $NetBSD: motg.c,v 1.1
 #include sys/proc.h
 #include sys/queue.h
 #include sys/select.h
+#include sys/sysctl.h
 #include sys/systm.h
 
 #include machine/endian.h
@@ -62,6 +63,7 @@ __KERNEL_RCSID(0, $NetBSD: motg.c,v 1.1
 #include dev/usb/usbdi.h
 #include dev/usb/usbdivar.h
 #include dev/usb/usb_mem.h
+#include dev/usb/usbhist.h
 
 #ifdef MOTG_ALLWINNER
 #include arch/arm/allwinner/awin_otgreg.h
@@ -72,19 +74,51 @@ __KERNEL_RCSID(0, $NetBSD: motg.c,v 1.1
 #include dev/usb/motgvar.h
 #include dev/usb/usbroothub.h
 
-#define MOTG_DEBUG
-#ifdef MOTG_DEBUG
-#define DPRINTF(x)	if (motgdebug) printf x
-#define DPRINTFN(n,x)	if (motgdebug  (n)) printf x
+#ifdef USB_DEBUG
+#ifndef MOTG_DEBUG
+#define motgdebug 0
+#else
+int motgdebug = 0;
+
+SYSCTL_SETUP(sysctl_hw_motg_setup, sysctl hw.motg setup)
+{
+	int err;
+	const struct sysctlnode *rnode;
+	const struct sysctlnode 

CVS commit: src/sys/kern

2015-03-09 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Mon Mar  9 15:35:11 UTC 2015

Modified Files:
src/sys/kern: subr_device.c vfs_mount.c

Log Message:
The use of root_device is not limited to vfs, so don't supply it in
vfs_mount.c, use subr_device.c instead.

Fixes rump kernels built with DEBUG by again not making the base depend
on the vfs faction, as reported by Patrick Welche.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sys/kern/subr_device.c
cvs rdiff -u -r1.32 -r1.33 src/sys/kern/vfs_mount.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/subr_device.c
diff -u src/sys/kern/subr_device.c:1.2 src/sys/kern/subr_device.c:1.3
--- src/sys/kern/subr_device.c:1.2	Sun Jan 31 15:10:12 2010
+++ src/sys/kern/subr_device.c	Mon Mar  9 15:35:11 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: subr_device.c,v 1.2 2010/01/31 15:10:12 pooka Exp $	*/
+/*	$NetBSD: subr_device.c,v 1.3 2015/03/09 15:35:11 pooka Exp $	*/
 
 /*
  * Copyright (c) 2006 The NetBSD Foundation, Inc.
@@ -27,12 +27,15 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: subr_device.c,v 1.2 2010/01/31 15:10:12 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: subr_device.c,v 1.3 2015/03/09 15:35:11 pooka Exp $);
 
 #include sys/param.h
 #include sys/device.h
 #include sys/systm.h
 
+/* Root device. */
+device_t			root_device;
+
 /*
  * Accessor functions for the device_t type.
  */

Index: src/sys/kern/vfs_mount.c
diff -u src/sys/kern/vfs_mount.c:1.32 src/sys/kern/vfs_mount.c:1.33
--- src/sys/kern/vfs_mount.c:1.32	Thu Jan  8 12:06:50 2015
+++ src/sys/kern/vfs_mount.c	Mon Mar  9 15:35:11 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: vfs_mount.c,v 1.32 2015/01/08 12:06:50 hannken Exp $	*/
+/*	$NetBSD: vfs_mount.c,v 1.33 2015/03/09 15:35:11 pooka Exp $	*/
 
 /*-
  * Copyright (c) 1997-2011 The NetBSD Foundation, Inc.
@@ -67,7 +67,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: vfs_mount.c,v 1.32 2015/01/08 12:06:50 hannken Exp $);
+__KERNEL_RCSID(0, $NetBSD: vfs_mount.c,v 1.33 2015/03/09 15:35:11 pooka Exp $);
 
 #define _VFS_VNODE_PRIVATE
 
@@ -96,9 +96,8 @@ __KERNEL_RCSID(0, $NetBSD: vfs_mount.c,
 #include miscfs/syncfs/syncfs.h
 #include miscfs/specfs/specdev.h
 
-/* Root filesystem and device. */
+/* Root filesystem. */
 vnode_t *			rootvnode;
-device_t			root_device;
 
 /* Mounted filesystem list. */
 struct mntlist			mountlist;



CVS commit: src/distrib/i386/installimage

2015-03-09 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Mon Mar  9 18:12:48 UTC 2015

Modified Files:
src/distrib/i386/installimage: Makefile

Log Message:
match amd64, we ran out of space.


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/distrib/i386/installimage/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/i386/installimage/Makefile
diff -u src/distrib/i386/installimage/Makefile:1.6 src/distrib/i386/installimage/Makefile:1.7
--- src/distrib/i386/installimage/Makefile:1.6	Sat Nov 15 07:33:04 2014
+++ src/distrib/i386/installimage/Makefile	Mon Mar  9 14:12:47 2015
@@ -1,11 +1,11 @@
-#	$NetBSD: Makefile,v 1.6 2014/11/15 12:33:04 uebayasi Exp $
+#	$NetBSD: Makefile,v 1.7 2015/03/09 18:12:47 christos Exp $
 
 .include bsd.own.mk
 
 INSTIMGBASE=	NetBSD-${DISTRIBVER}-i386-install	# gives ${IMGBASE}.img
 
 BOOTDISK=	sd0			# for USB flash etc.
-INSTIMAGEMB?=	520			# for all installation binaries
+INSTIMAGEMB?=	550			# for all installation binaries
 
 PRIMARY_BOOT=		bootxx_ffsv1
 SECONDARY_BOOT=		boot



CVS commit: src/sys/external/bsd/compiler_rt/dist/lib/builtins

2015-03-09 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Mon Mar  9 17:28:11 UTC 2015

Modified Files:
src/sys/external/bsd/compiler_rt/dist/lib/builtins:
gcc_personality_v0.c

Log Message:
Don't use __gcc_personality_sj0 on ARM.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.2 -r1.2 \
src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c
diff -u src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c:1.1.1.2 src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c:1.2
--- src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c:1.1.1.2	Tue Mar 18 22:28:43 2014
+++ src/sys/external/bsd/compiler_rt/dist/lib/builtins/gcc_personality_v0.c	Mon Mar  9 17:28:11 2015
@@ -180,7 +180,7 @@ static uintptr_t readEncodedPointer(cons
  * on each frame as the stack is unwound during a C++ exception
  * throw through a C function compiled with -fexceptions.
  */
-#if __arm__
+#if __USING_SJLJ_EXCEPTIONS__
 // the setjump-longjump based exceptions personality routine has a different name
 COMPILER_RT_ABI _Unwind_Reason_Code
 __gcc_personality_sj0(int version, _Unwind_Action actions,



CVS commit: [netbsd-7] src/doc

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 17:46:33 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
amend ticket 577


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.223 -r1.1.2.224 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.223 src/doc/CHANGES-7.0:1.1.2.224
--- src/doc/CHANGES-7.0:1.1.2.223	Mon Mar  9 09:23:36 2015
+++ src/doc/CHANGES-7.0	Mon Mar  9 17:46:33 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.223 2015/03/09 09:23:36 snj Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.224 2015/03/09 17:46:33 snj Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -18291,6 +18291,8 @@ sys/sys/device.h1.147
 sys/arch/powerpc/booke/dev/pq3sdhc.c		1.6
 sys/dev/sdmmc/sdhc.c1.54
 sys/dev/sdmmc/sdmmc.c1.24
+sys/dev/sdmmc/sdmmc_mem.c			1.34
+sys/dev/sdmmc/sdmmcvar.h			1.16
 
 	eSDHC has no DMA_BOUNDARY in BLOCK_SIZE register.
 	So clear multi segment DMA transfer support bit.



CVS commit: [netbsd-7] src/sys/dev/sdmmc

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 17:45:57 UTC 2015

Modified Files:
src/sys/dev/sdmmc [netbsd-7]: sdmmc_mem.c sdmmcvar.h

Log Message:
Pull up following revision(s) (requested by nonaka in ticket #577):
sys/dev/sdmmc/sdmmc_mem.c: revision 1.34
sys/dev/sdmmc/sdmmcvar.h: revision 1.16
fix to simulate multi-segment dma transfer for pq3sdhc(4).


To generate a diff of this commit:
cvs rdiff -u -r1.31.4.1 -r1.31.4.2 src/sys/dev/sdmmc/sdmmc_mem.c
cvs rdiff -u -r1.15 -r1.15.4.1 src/sys/dev/sdmmc/sdmmcvar.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/sdmmc/sdmmc_mem.c
diff -u src/sys/dev/sdmmc/sdmmc_mem.c:1.31.4.1 src/sys/dev/sdmmc/sdmmc_mem.c:1.31.4.2
--- src/sys/dev/sdmmc/sdmmc_mem.c:1.31.4.1	Mon Feb 16 21:25:34 2015
+++ src/sys/dev/sdmmc/sdmmc_mem.c	Mon Mar  9 17:45:57 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: sdmmc_mem.c,v 1.31.4.1 2015/02/16 21:25:34 martin Exp $	*/
+/*	$NetBSD: sdmmc_mem.c,v 1.31.4.2 2015/03/09 17:45:57 snj Exp $	*/
 /*	$OpenBSD: sdmmc_mem.c,v 1.10 2009/01/09 10:55:22 jsg Exp $	*/
 
 /*
@@ -45,7 +45,7 @@
 /* Routines for SD/MMC memory cards. */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sdmmc_mem.c,v 1.31.4.1 2015/02/16 21:25:34 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: sdmmc_mem.c,v 1.31.4.2 2015/03/09 17:45:57 snj Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_sdmmc.h
@@ -87,10 +87,14 @@ static int sdmmc_mem_single_read_block(s
 u_char *, size_t);
 static int sdmmc_mem_single_write_block(struct sdmmc_function *, uint32_t,
 u_char *, size_t);
-static int sdmmc_mem_read_block_subr(struct sdmmc_function *, uint32_t,
-u_char *, size_t);
-static int sdmmc_mem_write_block_subr(struct sdmmc_function *, uint32_t,
-u_char *, size_t);
+static int sdmmc_mem_single_segment_dma_read_block(struct sdmmc_function *,
+uint32_t, u_char *, size_t);
+static int sdmmc_mem_single_segment_dma_write_block(struct sdmmc_function *,
+uint32_t, u_char *, size_t);
+static int sdmmc_mem_read_block_subr(struct sdmmc_function *, bus_dmamap_t,
+uint32_t, u_char *, size_t);
+static int sdmmc_mem_write_block_subr(struct sdmmc_function *, bus_dmamap_t,
+uint32_t, u_char *, size_t);
 
 /*
  * Initialize SD/MMC memory cards and memory in SDIO combo cards.
@@ -1242,7 +1246,7 @@ static int
 sdmmc_mem_single_read_block(struct sdmmc_function *sf, uint32_t blkno,
 u_char *data, size_t datalen)
 {
-	struct sdmmc_softc *sc __diagused = sf-sc;
+	struct sdmmc_softc *sc = sf-sc;
 	int error = 0;
 	int i;
 
@@ -1250,7 +1254,7 @@ sdmmc_mem_single_read_block(struct sdmmc
 	KASSERT(!ISSET(sc-sc_caps, SMC_CAPS_DMA));
 
 	for (i = 0; i  datalen / SDMMC_SECTOR_SIZE; i++) {
-		error = sdmmc_mem_read_block_subr(sf, blkno + i,
+		error = sdmmc_mem_read_block_subr(sf, sc-sc_dmap, blkno + i,
 		data + i * SDMMC_SECTOR_SIZE, SDMMC_SECTOR_SIZE);
 		if (error)
 			break;
@@ -1258,13 +1262,81 @@ sdmmc_mem_single_read_block(struct sdmmc
 	return error;
 }
 
+/*
+ * Simulate multi-segment dma transfer.
+ */
 static int
-sdmmc_mem_read_block_subr(struct sdmmc_function *sf, uint32_t blkno,
-u_char *data, size_t datalen)
+sdmmc_mem_single_segment_dma_read_block(struct sdmmc_function *sf,
+uint32_t blkno, u_char *data, size_t datalen)
+{
+	struct sdmmc_softc *sc = sf-sc;
+	bool use_bbuf = false;
+	int error = 0;
+	int i;
+
+	for (i = 0; i  sc-sc_dmap-dm_nsegs; i++) {
+		size_t len = sc-sc_dmap-dm_segs[i].ds_len;
+		if ((len % SDMMC_SECTOR_SIZE) != 0) {
+			use_bbuf = true;
+			break;
+		}
+	}
+	if (use_bbuf) {
+		bus_dmamap_sync(sc-sc_dmat, sf-bbuf_dmap, 0, datalen,
+		BUS_DMASYNC_PREREAD);
+
+		error = sdmmc_mem_read_block_subr(sf, sf-bbuf_dmap,
+		blkno, data, datalen);
+		if (error) {
+			bus_dmamap_unload(sc-sc_dmat, sf-bbuf_dmap);
+			return error;
+		}
+
+		bus_dmamap_sync(sc-sc_dmat, sf-bbuf_dmap, 0, datalen,
+		BUS_DMASYNC_POSTREAD);
+
+		/* Copy from bounce buffer */
+		memcpy(data, sf-bbuf, datalen);
+
+		return 0;
+	}
+
+	for (i = 0; i  sc-sc_dmap-dm_nsegs; i++) {
+		size_t len = sc-sc_dmap-dm_segs[i].ds_len;
+
+		error = bus_dmamap_load(sc-sc_dmat, sf-sseg_dmap,
+		data, len, NULL, BUS_DMA_NOWAIT|BUS_DMA_READ);
+		if (error)
+			return error;
+
+		bus_dmamap_sync(sc-sc_dmat, sf-sseg_dmap, 0, len,
+		BUS_DMASYNC_PREREAD);
+
+		error = sdmmc_mem_read_block_subr(sf, sf-sseg_dmap,
+		blkno, data, len);
+		if (error) {
+			bus_dmamap_unload(sc-sc_dmat, sf-sseg_dmap);
+			return error;
+		}
+
+		bus_dmamap_sync(sc-sc_dmat, sf-sseg_dmap, 0, len,
+		BUS_DMASYNC_POSTREAD);
+
+		bus_dmamap_unload(sc-sc_dmat, sf-sseg_dmap);
+
+		blkno += len / SDMMC_SECTOR_SIZE;
+		data += len;
+	}
+	return 0;
+}
+
+static int
+sdmmc_mem_read_block_subr(struct sdmmc_function *sf, bus_dmamap_t dmap,
+uint32_t blkno, u_char *data, size_t datalen)
 {
 	struct sdmmc_softc *sc = sf-sc;
 	struct sdmmc_command cmd;
-	int error, bbuf, seg, 

CVS commit: src/sys/arch/evbarm/conf

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Mar  9 22:05:06 UTC 2015

Modified Files:
src/sys/arch/evbarm/conf: README.evbarm

Log Message:
Note RPI2


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/evbarm/conf/README.evbarm

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/README.evbarm
diff -u src/sys/arch/evbarm/conf/README.evbarm:1.8 src/sys/arch/evbarm/conf/README.evbarm:1.9
--- src/sys/arch/evbarm/conf/README.evbarm:1.8	Fri Jul 25 11:22:50 2014
+++ src/sys/arch/evbarm/conf/README.evbarm	Mon Mar  9 22:05:06 2015
@@ -1,4 +1,4 @@
-$NetBSD: README.evbarm,v 1.8 2014/07/25 11:22:50 hkenken Exp $
+$NetBSD: README.evbarm,v 1.9 2015/03/09 22:05:06 skrll Exp $
 
 config		date		boards
 ---
@@ -46,6 +46,7 @@ SHEEVAPLUG	2010/10/02	Marvell SheevaPlug
 SMDK2410	2003/07/31	Samsung SMDK2410 S3C2410 eval board
 SMDK2800	2002/11/20	Samsung SMDK2800 S3C2800 eval board
 RPI		2012/07/26	Raspberry Pi
+RPI2		2015/03/04	Raspberry Pi 2
 TEAMASA_NPWR	2002/02/07	Team ASA Npwr IOP310 based server appliance
 TEAMASA_NPWR_FC	2003/12/24	Team ASA NPWR-FC i80321 server appliance
 TISDP2420	2008/04/27	TI OMAP 2420 eval board



CVS commit: src/bin/pax

2015-03-09 Thread Sevan Janiyan
Module Name:src
Committed By:   sevan
Date:   Mon Mar  9 23:38:08 UTC 2015

Modified Files:
src/bin/pax: ar_io.c

Log Message:
From OpenBSD r1.49
Fix comment grammar


To generate a diff of this commit:
cvs rdiff -u -r1.55 -r1.56 src/bin/pax/ar_io.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/bin/pax/ar_io.c
diff -u src/bin/pax/ar_io.c:1.55 src/bin/pax/ar_io.c:1.56
--- src/bin/pax/ar_io.c:1.55	Fri Aug  8 14:48:55 2014
+++ src/bin/pax/ar_io.c	Mon Mar  9 23:38:08 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ar_io.c,v 1.55 2014/08/08 14:48:55 joerg Exp $	*/
+/*	$NetBSD: ar_io.c,v 1.56 2015/03/09 23:38:08 sevan Exp $	*/
 
 /*-
  * Copyright (c) 1992 Keith Muller.
@@ -42,7 +42,7 @@
 #if 0
 static char sccsid[] = @(#)ar_io.c	8.2 (Berkeley) 4/18/94;
 #else
-__RCSID($NetBSD: ar_io.c,v 1.55 2014/08/08 14:48:55 joerg Exp $);
+__RCSID($NetBSD: ar_io.c,v 1.56 2015/03/09 23:38:08 sevan Exp $);
 #endif
 #endif /* not lint */
 
@@ -255,7 +255,7 @@ ar_open(const char *name)
 	}
 
 	/*
-	 * make sure we beyond any doubt that we only can unlink regular files
+	 * make sure beyond any doubt that we can unlink only regular files
 	 * we created
 	 */
 	if (artyp != ISREG)



CVS commit: src/sys/arch/arm/include

2015-03-09 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Mon Mar  9 11:03:19 UTC 2015

Modified Files:
src/sys/arch/arm/include: sysarch.h

Log Message:
Provide size_t.


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/sys/arch/arm/include/sysarch.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uhci.c
diff -u src/sys/dev/usb/uhci.c:1.264.4.22 src/sys/dev/usb/uhci.c:1.264.4.23
--- src/sys/dev/usb/uhci.c:1.264.4.22	Tue Mar  3 06:23:43 2015
+++ src/sys/dev/usb/uhci.c	Tue Mar 10 05:57:15 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uhci.c,v 1.264.4.22 2015/03/03 06:23:43 skrll Exp $	*/
+/*	$NetBSD: uhci.c,v 1.264.4.23 2015/03/10 05:57:15 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2011, 2012 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.22 2015/03/03 06:23:43 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.23 2015/03/10 05:57:15 skrll Exp $);
 
 #include sys/param.h
 
@@ -64,7 +64,6 @@ __KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.2
 #include dev/usb/usbdi.h
 #include dev/usb/usbdivar.h
 #include dev/usb/usb_mem.h
-#include dev/usb/usb_quirks.h
 
 #include dev/usb/uhcireg.h
 #include dev/usb/uhcivar.h



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Tue Mar 10 05:59:10 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: uhci.c

Log Message:
Whitespace


To generate a diff of this commit:
cvs rdiff -u -r1.264.4.23 -r1.264.4.24 src/sys/dev/usb/uhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uhci.c
diff -u src/sys/dev/usb/uhci.c:1.264.4.23 src/sys/dev/usb/uhci.c:1.264.4.24
--- src/sys/dev/usb/uhci.c:1.264.4.23	Tue Mar 10 05:57:15 2015
+++ src/sys/dev/usb/uhci.c	Tue Mar 10 05:59:10 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uhci.c,v 1.264.4.23 2015/03/10 05:57:15 skrll Exp $	*/
+/*	$NetBSD: uhci.c,v 1.264.4.24 2015/03/10 05:59:10 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2011, 2012 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.23 2015/03/10 05:57:15 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: uhci.c,v 1.264.4.24 2015/03/10 05:59:10 skrll Exp $);
 
 #include sys/param.h
 
@@ -502,7 +502,7 @@ uhci_init(uhci_softc_t *sc)
 	 * queue heads and the interrupt queue heads at the control
 	 * queue head and point the physical frame list to the virtual.
 	 */
-	for(i = 0; i  UHCI_VFRAMELIST_COUNT; i++) {
+	for (i = 0; i  UHCI_VFRAMELIST_COUNT; i++) {
 		std = uhci_alloc_std(sc);
 		sqh = uhci_alloc_sqh(sc);
 		if (std == NULL || sqh == NULL)
@@ -554,7 +554,7 @@ uhci_init(uhci_softc_t *sc)
 
 	DPRINTFN(1, Enabling..., 0, 0, 0, 0);
 
-	err =  uhci_run(sc, 1, 0);		/* and here we go... */
+	err = uhci_run(sc, 1, 0);		/* and here we go... */
 	UWRITE2(sc, UHCI_INTR, UHCI_INTR_TOCRCIE | UHCI_INTR_RIE |
 		UHCI_INTR_IOCE | UHCI_INTR_SPIE);	/* enable interrupts */
 	return err;
@@ -871,7 +871,7 @@ uhci_dump_tds(uhci_soft_td_t *std)
 	uhci_soft_td_t *td;
 	int stop;
 
-	for(td = std; td != NULL; td = td-link.std) {
+	for (td = std; td != NULL; td = td-link.std) {
 		uhci_dump_td(td);
 
 		/*



CVS commit: [netbsd-7] src/sys/dev

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 08:00:46 UTC 2015

Modified Files:
src/sys/dev [netbsd-7]: cons.c

Log Message:
Pull up following revision(s) (requested by nakayama in ticket #574):
sys/dev/cons.c: revision 1.74
Fix strange kernel output sequence \n\r observed in serial
consoles.  Output '\r' before '\n' in conversion.


To generate a diff of this commit:
cvs rdiff -u -r1.72 -r1.72.2.1 src/sys/dev/cons.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/cons.c
diff -u src/sys/dev/cons.c:1.72 src/sys/dev/cons.c:1.72.2.1
--- src/sys/dev/cons.c:1.72	Fri Jul 25 08:10:35 2014
+++ src/sys/dev/cons.c	Mon Mar  9 08:00:46 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: cons.c,v 1.72 2014/07/25 08:10:35 dholland Exp $	*/
+/*	$NetBSD: cons.c,v 1.72.2.1 2015/03/09 08:00:46 snj Exp $	*/
 
 /*
  * Copyright (c) 1988 University of Utah.
@@ -39,7 +39,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: cons.c,v 1.72 2014/07/25 08:10:35 dholland Exp $);
+__KERNEL_RCSID(0, $NetBSD: cons.c,v 1.72.2.1 2015/03/09 08:00:46 snj Exp $);
 
 #include sys/param.h
 #include sys/proc.h
@@ -314,11 +314,11 @@ cnputc(int c)
 		return;
 
 	if (c) {
-		(*cn_tab-cn_putc)(cn_tab-cn_dev, c);
 		if (c == '\n') {
-			docritpollhooks();
 			(*cn_tab-cn_putc)(cn_tab-cn_dev, '\r');
+			docritpollhooks();
 		}
+		(*cn_tab-cn_putc)(cn_tab-cn_dev, c);
 	}
 }
 



CVS commit: [netbsd-7] xsrc/external/mit/xf86-video-ati-kms

2015-03-09 Thread Soren Jacobsen
Module Name:xsrc
Committed By:   snj
Date:   Mon Mar  9 08:33:33 UTC 2015

Added Files:
xsrc/external/mit/xf86-video-ati-kms/dist [netbsd-7]: COPYING ChangeLog
INSTALL Makefile.am Makefile.in README aclocal.m4 compile
config.guess config.h.in config.sub configure configure.ac depcomp
install-sh ltmain.sh missing
xsrc/external/mit/xf86-video-ati-kms/dist/man [netbsd-7]: Makefile.am
Makefile.in ati.man radeon.man
xsrc/external/mit/xf86-video-ati-kms/dist/src [netbsd-7]: Makefile.am
Makefile.in ati.c ati.h ati_pciids_gen.h atimodule.c atipciids.h
atipcirename.h ativersion.h bicubic_table.h bicubic_table.py
cayman_accel.c cayman_reg.h cayman_reg_auto.h cayman_shader.c
cayman_shader.h compat-api.h drmmode_display.c drmmode_display.h
evergreen_accel.c evergreen_exa.c evergreen_reg.h
evergreen_reg_auto.h evergreen_shader.c evergreen_shader.h
evergreen_state.h evergreen_textured_videofuncs.c r600_exa.c
r600_reg.h r600_reg_auto_r6xx.h r600_reg_r6xx.h r600_reg_r7xx.h
r600_shader.c r600_shader.h r600_state.h r600_textured_videofuncs.c
r6xx_accel.c radeon.h radeon_accel.c radeon_bo_helper.c
radeon_bo_helper.h radeon_chipinfo_gen.h radeon_chipset_gen.h
radeon_dri2.c radeon_dri2.h radeon_exa.c radeon_exa_funcs.c
radeon_exa_render.c radeon_exa_shared.c radeon_exa_shared.h
radeon_glamor.c radeon_glamor.h radeon_kms.c radeon_misc.c
radeon_pci_chipset_gen.h radeon_pci_device_match_gen.h
radeon_probe.c radeon_probe.h radeon_reg.h radeon_textured_video.c
radeon_textured_videofuncs.c radeon_vbo.c radeon_vbo.h
radeon_version.h radeon_video.c radeon_video.h radeon_xvmc.c
simple_list.h
xsrc/external/mit/xf86-video-ati-kms/dist/src/pcidb [netbsd-7]:
ati_pciids.csv parse_pci_ids.pl
xsrc/external/mit/xf86-video-ati-kms/include [netbsd-7]: config.h

Log Message:
Pull up following revision(s) (requested by mrg in ticket #575):
external/mit/xf86-video-ati-kms/dist/COPYING: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/ChangeLog: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/INSTALL: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/Makefile.am: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/Makefile.in: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/README: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/aclocal.m4: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/compile: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/config.guess: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/config.h.in: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/config.sub: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/configure: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/configure.ac: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/depcomp: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/install-sh: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/ltmain.sh: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/man/Makefile.am: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/man/Makefile.in: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/man/ati.man: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/man/radeon.man: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/missing: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/Makefile.am: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/Makefile.in: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/ati.c: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/ati.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/ati_pciids_gen.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/atimodule.c: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/atipciids.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/atipcirename.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/ativersion.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/bicubic_table.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/bicubic_table.py: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/cayman_accel.c: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/cayman_reg.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/cayman_reg_auto.h: up to 
1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/cayman_shader.c: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/cayman_shader.h: up to 1.1.1.1
external/mit/xf86-video-ati-kms/dist/src/compat-api.h: up to 1.1.1.1

CVS commit: [netbsd-7] src

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 08:45:27 UTC 2015

Modified Files:
src/distrib/sets [netbsd-7]: mkvars.mk sets.subr
src/distrib/sets/lists/xdebug [netbsd-7]: md.amd64 md.i386
src/distrib/sets/lists/xserver [netbsd-7]: md.amd64 md.i386
src/external/mit/xorg/server/drivers [netbsd-7]: Makefile
src/share/mk [netbsd-7]: bsd.README bsd.own.mk
Added Files:
src/external/mit/xorg/server/drivers/xf86-video-radeon-kms [netbsd-7]:
Makefile

Log Message:
Pull up following revision(s) (requested by mrg in ticket #575):
distrib/sets/mkvars.mk: revision 1.16
distrib/sets/sets.subr: revision 1.163
distrib/sets/lists/xdebug/md.amd64: revision 1.11
distrib/sets/lists/xdebug/md.i386: revision 1.12
distrib/sets/lists/xserver/md.amd64: revision 1.76
distrib/sets/lists/xserver/md.i386: revision 1.95
external/mit/xorg/server/drivers/Makefile: revision 1.64
external/mit/xorg/server/drivers/xf86-video-radeon-kms/Makefile: 
revision 1.1
share/mk/bsd.README: revision 1.338
share/mk/bsd.own.mk: revision 1.844
add build framework to choose between xf86-video-ati 6.x (UMS/KMS)
and 7.x (KMS only), and switch x86 to the latest (KMS only) version.
(if someone can make x86 install both radeon_drv.so.[67] and leave
the default symlink to .7, that would be nice.  renaming it so that
it's easier to choose via xorg.conf is a little more tricky..)


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.15.4.1 src/distrib/sets/mkvars.mk
cvs rdiff -u -r1.160.4.1 -r1.160.4.2 src/distrib/sets/sets.subr
cvs rdiff -u -r1.6.4.2 -r1.6.4.3 src/distrib/sets/lists/xdebug/md.amd64
cvs rdiff -u -r1.6.4.3 -r1.6.4.4 src/distrib/sets/lists/xdebug/md.i386
cvs rdiff -u -r1.73.4.2 -r1.73.4.3 src/distrib/sets/lists/xserver/md.amd64
cvs rdiff -u -r1.92.4.2 -r1.92.4.3 src/distrib/sets/lists/xserver/md.i386
cvs rdiff -u -r1.63 -r1.63.10.1 src/external/mit/xorg/server/drivers/Makefile
cvs rdiff -u -r0 -r1.1.2.2 \
src/external/mit/xorg/server/drivers/xf86-video-radeon-kms/Makefile
cvs rdiff -u -r1.335 -r1.335.2.1 src/share/mk/bsd.README
cvs rdiff -u -r1.829.2.4 -r1.829.2.5 src/share/mk/bsd.own.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/mkvars.mk
diff -u src/distrib/sets/mkvars.mk:1.15 src/distrib/sets/mkvars.mk:1.15.4.1
--- src/distrib/sets/mkvars.mk:1.15	Sun Jan 26 21:33:53 2014
+++ src/distrib/sets/mkvars.mk	Mon Mar  9 08:45:26 2015
@@ -1,4 +1,4 @@
-# $NetBSD: mkvars.mk,v 1.15 2014/01/26 21:33:53 joerg Exp $
+# $NetBSD: mkvars.mk,v 1.15.4.1 2015/03/09 08:45:26 snj Exp $
 
 MKEXTRAVARS= \
 	MACHINE \
@@ -21,6 +21,7 @@ MKEXTRAVARS= \
 	MKSOFTFLOAT \
 	MKXORG \
 	MKXORG_SERVER \
+	MKX11RADEONKMS \
 	X11FLAVOR \
 	USE_INET6 \
 	USE_KERBEROS \

Index: src/distrib/sets/sets.subr
diff -u src/distrib/sets/sets.subr:1.160.4.1 src/distrib/sets/sets.subr:1.160.4.2
--- src/distrib/sets/sets.subr:1.160.4.1	Tue Mar  3 08:28:12 2015
+++ src/distrib/sets/sets.subr	Mon Mar  9 08:45:26 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: sets.subr,v 1.160.4.1 2015/03/03 08:28:12 snj Exp $
+#	$NetBSD: sets.subr,v 1.160.4.2 2015/03/09 08:45:26 snj Exp $
 #
 
 #
@@ -179,7 +179,7 @@ SUBST=${SUBST};s#@MACHINE@#${MACHINE}#g
 # In each file, a record consists of a path and a System Package name,
 # separated by whitespace. E.g.,
 #
-# 	# $NetBSD: sets.subr,v 1.160.4.1 2015/03/03 08:28:12 snj Exp $
+# 	# $NetBSD: sets.subr,v 1.160.4.2 2015/03/09 08:45:26 snj Exp $
 # 	.			base-sys-root	[keyword[,...]]
 # 	./altroot		base-sys-root
 # 	./bin			base-sys-root
@@ -260,6 +260,7 @@ SUBST=${SUBST};s#@MACHINE@#${MACHINE}#g
 #	ssp			${HAVE_SSP} != no
 #	tpm			${MKTPM} != no
 #	x11			${MKX11} != no  ${X11FLAVOUR} != Xorg
+#	x11radeonkms		${MKX11} != no  ${MKX11RADEONKMS} != no
 #	xorg			${MKX11} != no  ${X11FLAVOUR} == Xorg
 #	xorg_server		${MKXORG_SERVER} != no
 #	yp			${MKYP} != no

Index: src/distrib/sets/lists/xdebug/md.amd64
diff -u src/distrib/sets/lists/xdebug/md.amd64:1.6.4.2 src/distrib/sets/lists/xdebug/md.amd64:1.6.4.3
--- src/distrib/sets/lists/xdebug/md.amd64:1.6.4.2	Tue Mar  3 08:28:12 2015
+++ src/distrib/sets/lists/xdebug/md.amd64	Mon Mar  9 08:45:26 2015
@@ -1,4 +1,4 @@
-# $NetBSD: md.amd64,v 1.6.4.2 2015/03/03 08:28:12 snj Exp $
+# $NetBSD: md.amd64,v 1.6.4.3 2015/03/09 08:45:26 snj Exp $
 ./usr/X11R7/lib/libI810XvMC_g.a-unknown-	debuglib,xorg
 ./usr/X11R7/lib/libIntelXvMC_g.a			-unknown-	debuglib,xorg
 ./usr/X11R7/lib/libchromeXvMCPro_g.a			-unknown-	debuglib,xorg
@@ -148,7 +148,8 @@
 ./usr/libdata/debug/usr/X11R7/lib/modules/drivers/nv_drv.so.2.debug	-unknown-		xorg,debug
 ./usr/libdata/debug/usr/X11R7/lib/modules/drivers/openchrome_drv.so.0.debug	-unknown-		xorg,debug
 ./usr/libdata/debug/usr/X11R7/lib/modules/drivers/r128_drv.so.6.debug	-unknown-		xorg,debug

CVS commit: [netbsd-7] src/external/mit/xorg/server/drivers

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 08:47:19 UTC 2015

Modified Files:
src/external/mit/xorg/server/drivers [netbsd-7]: Makefile

Log Message:
Pull up following revision(s) (requested by mrg in ticket #575):
external/mit/xorg/server/drivers/Makefile: revision 1.65
fix the previous; it had a reversed test and was also missing bsd.own.mk
before checking MK* values.


To generate a diff of this commit:
cvs rdiff -u -r1.63.10.1 -r1.63.10.2 \
src/external/mit/xorg/server/drivers/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/server/drivers/Makefile
diff -u src/external/mit/xorg/server/drivers/Makefile:1.63.10.1 src/external/mit/xorg/server/drivers/Makefile:1.63.10.2
--- src/external/mit/xorg/server/drivers/Makefile:1.63.10.1	Mon Mar  9 08:45:26 2015
+++ src/external/mit/xorg/server/drivers/Makefile	Mon Mar  9 08:47:19 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.63.10.1 2015/03/09 08:45:26 snj Exp $
+#	$NetBSD: Makefile,v 1.63.10.2 2015/03/09 08:47:19 snj Exp $
 
 # xf86-input drivers
 
@@ -19,14 +19,15 @@ SUBDIR+= \
 
 .endif
 
-
 # xf86-video drivers
 
+.include bsd.own.mk
+
 # Set this to no to build the UMS-happy 6.x driver, vs KMS 7.x
-.if ${MKX11RADEONKMS:U} != no
-RADEON_SUBDIR=radeon
-.else
+.if ${MKX11RADEONKMS} != no
 RADEON_SUBDIR=radeon-kms
+.else
+RADEON_SUBDIR=radeon
 .endif
 
 .if ${MACHINE_ARCH} == i386 || \



CVS commit: [netbsd-7] src/libexec/ld.elf_so

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 07:56:43 UTC 2015

Modified Files:
src/libexec/ld.elf_so [netbsd-7]: rtld.c

Log Message:
Pull up following revision(s) (requested by skrll in ticket #569):
libexec/ld.elf_so/rtld.c: revision 1.175
HPPA hack for a problem where gdb doesn't see _rtld_debug_state when
it's a single bv,n %r0(%rp) instruction.
The nullify confuses something.


To generate a diff of this commit:
cvs rdiff -u -r1.173 -r1.173.4.1 src/libexec/ld.elf_so/rtld.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/libexec/ld.elf_so/rtld.c
diff -u src/libexec/ld.elf_so/rtld.c:1.173 src/libexec/ld.elf_so/rtld.c:1.173.4.1
--- src/libexec/ld.elf_so/rtld.c:1.173	Tue Mar 18 16:05:34 2014
+++ src/libexec/ld.elf_so/rtld.c	Mon Mar  9 07:56:43 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rtld.c,v 1.173 2014/03/18 16:05:34 joerg Exp $	 */
+/*	$NetBSD: rtld.c,v 1.173.4.1 2015/03/09 07:56:43 snj Exp $	 */
 
 /*
  * Copyright 1996 John D. Polstra.
@@ -40,7 +40,7 @@
 
 #include sys/cdefs.h
 #ifndef lint
-__RCSID($NetBSD: rtld.c,v 1.173 2014/03/18 16:05:34 joerg Exp $);
+__RCSID($NetBSD: rtld.c,v 1.173.4.1 2015/03/09 07:56:43 snj Exp $);
 #endif /* not lint */
 
 #include sys/param.h
@@ -1420,6 +1420,9 @@ _rtld_error(const char *fmt,...)
 void
 _rtld_debug_state(void)
 {
+#if defined(__hppa__)
+	__asm volatile(nop ::: memory);
+#endif
 
 	/* Prevent optimizer from removing calls to this function */
 	__insn_barrier();



CVS commit: [netbsd-7] src/sys/arch/i386/stand

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 09:07:58 UTC 2015

Modified Files:
src/sys/arch/i386/stand [netbsd-7]: Makefile.booters

Log Message:
Pull up following revision(s) (requested by martin in ticket #579):
sys/arch/i386/stand/Makefile.booters: revision 1.90
Compile the booblocks for i386 CPUs, even when the main target architecture
is amd64.
Fixes PR port-i386/49725.


To generate a diff of this commit:
cvs rdiff -u -r1.89 -r1.89.4.1 src/sys/arch/i386/stand/Makefile.booters

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/stand/Makefile.booters
diff -u src/sys/arch/i386/stand/Makefile.booters:1.89 src/sys/arch/i386/stand/Makefile.booters:1.89.4.1
--- src/sys/arch/i386/stand/Makefile.booters:1.89	Sun Jan 12 15:26:29 2014
+++ src/sys/arch/i386/stand/Makefile.booters	Mon Mar  9 09:07:58 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.booters,v 1.89 2014/01/12 15:26:29 tsutsui Exp $
+#	$NetBSD: Makefile.booters,v 1.89.4.1 2015/03/09 09:07:58 snj Exp $
 
 .include bsd.own.mk
 
@@ -14,7 +14,7 @@ LIBC=		# nothing
 # Make sure we override any optimization options specified by the
 # user.
 .if ${MACHINE_ARCH} == x86_64
-CPUFLAGS= -m32
+CPUFLAGS= -m32 -march=i386 -mtune=i386
 .else
 CPUFLAGS=  -march=i386 -mtune=i386
 .endif



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Mar  9 09:21:55 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: TODO.usbmp

Log Message:
Update


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.8.4.1 src/sys/dev/usb/TODO.usbmp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/TODO.usbmp
diff -u src/sys/dev/usb/TODO.usbmp:1.8 src/sys/dev/usb/TODO.usbmp:1.8.4.1
--- src/sys/dev/usb/TODO.usbmp:1.8	Sat Aug  2 15:50:16 2014
+++ src/sys/dev/usb/TODO.usbmp	Mon Mar  9 09:21:54 2015
@@ -1,4 +1,4 @@
-$NetBSD: TODO.usbmp,v 1.8 2014/08/02 15:50:16 skrll Exp $
+$NetBSD: TODO.usbmp,v 1.8.4.1 2015/03/09 09:21:54 skrll Exp $
 
 
 the majority of the USB MP device interface is documented in usbdivar.h.
@@ -9,6 +9,15 @@ flesh out most of usbdi(9).
 usb_event_thread() startup should use something to sync companions
 
 
+KERNEL_LOCK
+  - auvitek.c
+  - auvitek_dtv.c
+  - emdtv.c
+  - emdtv_dtv.c
+  - ubt.c
+  - uhub.c
+  - usscanner.c
+
 usb_detach_{waitold,wakeup} to usb_detach_{wait,broadcast} conversion:
   - drivers:
   if_aue.c
@@ -53,6 +62,32 @@ convert uhidev users to MPSAFE:
   uyurex(4)
   - sysmon -- hm?
 
+splusb drivers:
+  - auvitek_dtv.c
+  - auvitek_video.c
+  - emdtv_dtv.c
+  - if_athn_usb.c
+  - if_aue.c
+  - if_axe.c
+  - if_axen.c
+  - if_cdce.c
+  - if_cue.c
+  - if_kue.c
+  - if_otus.c
+  - if_rum.c
+  - if_run.c
+  - if_smsc.c
+  - if_udav.c
+  - if_upl.c
+  - if_ural.c
+  - if_url.c
+  - if_urndis.c
+  - if_urtw.c
+  - if_urtwn.c
+  - if_zyd.c
+  - ubt.c
+  - ucycom.c
+  - udsir.c
 
 wakeup/tsleep drivers:
   - if_athn_usb.c



CVS commit: [netbsd-7] src/sys/arch/sparc64/sparc64

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 07:54:13 UTC 2015

Modified Files:
src/sys/arch/sparc64/sparc64 [netbsd-7]: locore.s

Log Message:
Pull up following revision(s) (requested by nakayama in ticket #568):
sys/arch/sparc64/sparc64/locore.s: revision 1.379, 1.380
Use panic stack temporarily for calling prom_printf in a trap
handler.
It seems that openfirmware cannot handle over 4GB pointers, and
stack pointers may point to over 4GB since VA layout was rearranged
by rev 1.33 of vmparam.h.  Therefore, use panic stack to avoid
panicking in OF_write used by prom_printf.
--
PANICSTACK is a pointer itself, not a pointer to pointer.


To generate a diff of this commit:
cvs rdiff -u -r1.369.2.1 -r1.369.2.2 src/sys/arch/sparc64/sparc64/locore.s

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/sparc64/locore.s
diff -u src/sys/arch/sparc64/sparc64/locore.s:1.369.2.1 src/sys/arch/sparc64/sparc64/locore.s:1.369.2.2
--- src/sys/arch/sparc64/sparc64/locore.s:1.369.2.1	Thu Aug 14 06:50:37 2014
+++ src/sys/arch/sparc64/sparc64/locore.s	Mon Mar  9 07:54:12 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: locore.s,v 1.369.2.1 2014/08/14 06:50:37 martin Exp $	*/
+/*	$NetBSD: locore.s,v 1.369.2.2 2015/03/09 07:54:12 snj Exp $	*/
 
 /*
  * Copyright (c) 2006-2010 Matthew R. Green
@@ -2126,9 +2126,7 @@ winfixspill:
 	wrpr	%g0, 0, %otherwin
 	or	%lo(2f), %o0, %o0
 	wrpr	%g0, WSTATE_KERN, %wstate
-	sethi	%hi(PANICSTACK), %sp
-	LDPTR	[%sp + %lo(PANICSTACK)], %sp
-	add	%sp, -CC64FSZ-STKB, %sp
+	set	PANICSTACK-CC64FSZ-STKB, %sp
 	ta	1; nop	! This helps out traptrace.
 	call	_C_LABEL(panic)! This needs to be fixed properly but we should panic here
 	 mov	%g1, %o1
@@ -2908,9 +2906,7 @@ slowtrap:
 	cmp	%g7, WSTATE_KERN
 	bnz,pt	%icc, 1f		! User stack -- we'll blow it away
 	 nop
-	sethi	%hi(PANICSTACK), %sp
-	LDPTR	[%sp + %lo(PANICSTACK)], %sp
-	add	%sp, -CC64FSZ-STKB, %sp	
+	set	PANICSTACK-CC64FSZ-STKB, %sp
 1:
 #endif
 	rdpr	%tt, %g4
@@ -3528,7 +3524,8 @@ ret_from_intr_vector:
 	 nop
 #endif
 #if 1
-	STACKFRAME(-CC64FSZ)		! Get a clean register window
+	set	PANICSTACK-STKB, %g1	! Use panic stack temporarily
+	save	%g1, -CC64FSZ, %sp	! Get a clean register window
 	LOAD_ASCIZ(%o0, interrupt_vector: spurious vector %lx at pil %d\r\n)
 	mov	%g7, %o1
 	GLOBTOLOC



CVS commit: [netbsd-7] src/usr.sbin/cpuctl/arch

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 07:58:34 UTC 2015

Modified Files:
src/usr.sbin/cpuctl/arch [netbsd-7]: i386-asm.S x86_64-asm.S

Log Message:
Pull up following revision(s) (requested by tnn in ticket #570):
usr.sbin/cpuctl/arch/i386-asm.S: revision 1.4
usr.sbin/cpuctl/arch/x86_64-asm.S: revision 1.5
xgetbv expects XCR0 to be speficied in %ecx, don't leave %ecx undefined


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.3.8.1 src/usr.sbin/cpuctl/arch/i386-asm.S
cvs rdiff -u -r1.4 -r1.4.8.1 src/usr.sbin/cpuctl/arch/x86_64-asm.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/cpuctl/arch/i386-asm.S
diff -u src/usr.sbin/cpuctl/arch/i386-asm.S:1.3 src/usr.sbin/cpuctl/arch/i386-asm.S:1.3.8.1
--- src/usr.sbin/cpuctl/arch/i386-asm.S:1.3	Mon Jan  7 23:20:42 2013
+++ src/usr.sbin/cpuctl/arch/i386-asm.S	Mon Mar  9 07:58:34 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: i386-asm.S,v 1.3 2013/01/07 23:20:42 dsl Exp $	*/
+/*	$NetBSD: i386-asm.S,v 1.3.8.1 2015/03/09 07:58:34 snj Exp $	*/
 
 /*-
  * Copyright (c) 1998, 2000, 2004, 2006, 2007 The NetBSD Foundation, Inc.
@@ -49,6 +49,7 @@ ENTRY(x86_cpuid2)
 END(x86_cpuid2)
 
 ENTRY(x86_xgetbv)
+	xorl	%ecx, %ecx
 	xgetbv
 	ret
 END(x86_xgetbv)

Index: src/usr.sbin/cpuctl/arch/x86_64-asm.S
diff -u src/usr.sbin/cpuctl/arch/x86_64-asm.S:1.4 src/usr.sbin/cpuctl/arch/x86_64-asm.S:1.4.8.1
--- src/usr.sbin/cpuctl/arch/x86_64-asm.S:1.4	Mon Jan  7 23:20:42 2013
+++ src/usr.sbin/cpuctl/arch/x86_64-asm.S	Mon Mar  9 07:58:34 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: x86_64-asm.S,v 1.4 2013/01/07 23:20:42 dsl Exp $	*/
+/*	$NetBSD: x86_64-asm.S,v 1.4.8.1 2015/03/09 07:58:34 snj Exp $	*/
 
 /*-
  * Copyright (c) 2007 The NetBSD Foundation, Inc.
@@ -44,6 +44,7 @@ ENTRY(x86_cpuid2)
 	ret
 
 ENTRY(x86_xgetbv)
+	xorl	%ecx, %ecx
 	xgetbv
 	ret
 



CVS commit: [netbsd-7] xsrc/external/mit/xorg-server/dist

2015-03-09 Thread Soren Jacobsen
Module Name:xsrc
Committed By:   snj
Date:   Mon Mar  9 08:38:43 UTC 2015

Modified Files:
xsrc/external/mit/xorg-server/dist/exa [netbsd-7]: exa_unaccel.c
xsrc/external/mit/xorg-server/dist/glx [netbsd-7]: glxdri.c
xsrc/external/mit/xorg-server/dist/include [netbsd-7]: regionstr.h

Log Message:
Pull up following revision(s) (requested by mrg in ticket #575):
external/mit/xorg-server/dist/exa/exa_unaccel.c: revision 1.3
external/mit/xorg-server/dist/glx/glxdri.c: revision 1.6
external/mit/xorg-server/dist/include/regionstr.h: revision 1.5
port a change back from newer xorg-server, which is needed
for xf86-video-ati 7.x.
http://lists.x.org/archives/xorg-devel/2011-March/020990.html
commit 43e47433cf55c98db5308a51c1c514c59901f598
Author: Soren Sandmann Pedersen ssp at redhat.com
Date:   Tue Mar 29 13:06:36 2011 -0400
Add RegionInitBoxes(), and fix some buggy callers of RegionInit().
The interface to RegionInit():
RegionInit (RegionPtr pReg, BoxPtr rect, int size);
is very confusing because it doesn't take a list of boxes, it takes
*one* box, but if that box is NULL, it initializes an empty region
with 'size' rectangles preallocated.
Most callers of this function were correctly passing either NULL or
just one box, but there were three confused cases, where the code
seems to expect a region to be created from a list of boxes.
This patch adds a new function RegionInitBoxes() and fixes those
instances to call that instead.
And yes, the pixman function to initialize a region from a list of
boxes is called init_rects() because pixman is also awesome.
V2: Make RegionInitBoxes() return a Bool indicating whether the call
succeeded, and fix the callers to check this return value.
Signed-off-by: Soren Sandmann ssp at redhat.com


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.2.4.1 \
xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c
cvs rdiff -u -r1.5 -r1.5.10.1 xsrc/external/mit/xorg-server/dist/glx/glxdri.c
cvs rdiff -u -r1.1.1.3.10.1 -r1.1.1.3.10.2 \
xsrc/external/mit/xorg-server/dist/include/regionstr.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c
diff -u xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c:1.2 xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c:1.2.4.1
--- xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c:1.2	Fri Nov  9 10:27:33 2012
+++ xsrc/external/mit/xorg-server/dist/exa/exa_unaccel.c	Mon Mar  9 08:38:43 2015
@@ -127,11 +127,10 @@ ExaCheckCopyNtoN (DrawablePtr pSrc, Draw
 EXA_FALLBACK((from %p to %p (%c,%c)\n, pSrc, pDst,
 		  exaDrawableLocation(pSrc), exaDrawableLocation(pDst)));
 
-if (pExaScr-prepare_access_reg) {
+if (pExaScr-prepare_access_reg  RegionInitBoxes(reg, pbox, nbox)) {
 	PixmapPtr pPixmap = exaGetDrawablePixmap(pSrc);
 
 	exaGetDrawableDeltas(pSrc, pPixmap, xoff, yoff);
-	RegionInit(reg, pbox, nbox);
 	RegionTranslate(reg, xoff + dx, yoff + dy);
 	pExaScr-prepare_access_reg(pPixmap, EXA_PREPARE_SRC, reg);
 	RegionUninit(reg);
@@ -140,11 +139,11 @@ ExaCheckCopyNtoN (DrawablePtr pSrc, Draw
 
 if (pExaScr-prepare_access_reg 
 	!exaGCReadsDestination(pDst, pGC-planemask, pGC-fillStyle,
-			   pGC-alu, pGC-clientClipType)) {
+			   pGC-alu, pGC-clientClipType) 
+			   RegionInitBoxes (reg, pbox, nbox)) {
 	PixmapPtr pPixmap = exaGetDrawablePixmap(pDst);
 
 	exaGetDrawableDeltas(pSrc, pPixmap, xoff, yoff);
-	RegionInit(reg, pbox, nbox);
 	RegionTranslate(reg, xoff, yoff);
 	pExaScr-prepare_access_reg(pPixmap, EXA_PREPARE_DEST, reg);
 	RegionUninit(reg);

Index: xsrc/external/mit/xorg-server/dist/glx/glxdri.c
diff -u xsrc/external/mit/xorg-server/dist/glx/glxdri.c:1.5 xsrc/external/mit/xorg-server/dist/glx/glxdri.c:1.5.10.1
--- xsrc/external/mit/xorg-server/dist/glx/glxdri.c:1.5	Tue Aug  2 07:15:02 2011
+++ xsrc/external/mit/xorg-server/dist/glx/glxdri.c	Mon Mar  9 08:38:43 2015
@@ -831,10 +831,19 @@ static void __glXReportDamage(__DRIdrawa
 
 __glXenterServer(GL_FALSE);
 
-RegionInit(region, (BoxPtr) rects, num_rects);
-RegionTranslate(region, pDraw-x, pDraw-y);
-DamageDamageRegion(pDraw, region);
-RegionUninit(region);
+if (RegionInitBoxes(region, (BoxPtr) rects, num_rects)) {
+   RegionTranslate(region, pDraw-x, pDraw-y);
+   DamageDamageRegion(pDraw, region);
+   RegionUninit(region);
+}
+else {
+   while (num_rects--) {
+   RegionInit (region, (BoxPtr) rects++, 1);
+   RegionTranslate(region, pDraw-x, pDraw-y);
+   DamageDamageRegion(pDraw, region);
+   RegionUninit(region);
+   }
+}
 
 __glXleaveServer(GL_FALSE);
 }

Index: xsrc/external/mit/xorg-server/dist/include/regionstr.h
diff -u xsrc/external/mit/xorg-server/dist/include/regionstr.h:1.1.1.3.10.1 

CVS commit: [netbsd-7] src/sys

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 08:56:02 UTC 2015

Modified Files:
src/sys/kern [netbsd-7]: init_main.c subr_autoconf.c
src/sys/sys [netbsd-7]: device.h

Log Message:
Pull up following revision(s) (requested by mrg in ticket #576):
sys/kern/init_main.c: revision 1.462
sys/kern/subr_autoconf.c: revision 1.234
sys/sys/device.h: revision 1.147
wait for config_mountroot threads to complete before we tell init it
can start up.  this solves the problem where a console device needs
mountroot to complete attaching, and must create wsdisplay0 before
init tries to open /dev/console.  fixes PR#49709.
XXX: pullup-7


To generate a diff of this commit:
cvs rdiff -u -r1.458.2.1 -r1.458.2.2 src/sys/kern/init_main.c
cvs rdiff -u -r1.231 -r1.231.2.1 src/sys/kern/subr_autoconf.c
cvs rdiff -u -r1.144 -r1.144.4.1 src/sys/sys/device.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/init_main.c
diff -u src/sys/kern/init_main.c:1.458.2.1 src/sys/kern/init_main.c:1.458.2.2
--- src/sys/kern/init_main.c:1.458.2.1	Fri Aug 15 12:58:45 2014
+++ src/sys/kern/init_main.c	Mon Mar  9 08:56:01 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: init_main.c,v 1.458.2.1 2014/08/15 12:58:45 martin Exp $	*/
+/*	$NetBSD: init_main.c,v 1.458.2.2 2015/03/09 08:56:01 snj Exp $	*/
 
 /*-
  * Copyright (c) 2008, 2009 The NetBSD Foundation, Inc.
@@ -97,7 +97,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: init_main.c,v 1.458.2.1 2014/08/15 12:58:45 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: init_main.c,v 1.458.2.2 2015/03/09 08:56:01 snj Exp $);
 
 #include opt_ddb.h
 #include opt_ipsec.h
@@ -712,6 +712,9 @@ main(void)
 	uvm_aiodone_worker, NULL, PRI_VM, IPL_NONE, WQ_MPSAFE))
 		panic(fork aiodoned);
 
+	/* Wait for final configure threads to complete. */
+	config_finalize_mountroot();
+
 	/*
 	 * Okay, now we can let init(8) exec!  It's off to userland!
 	 */

Index: src/sys/kern/subr_autoconf.c
diff -u src/sys/kern/subr_autoconf.c:1.231 src/sys/kern/subr_autoconf.c:1.231.2.1
--- src/sys/kern/subr_autoconf.c:1.231	Sun Aug 10 16:44:36 2014
+++ src/sys/kern/subr_autoconf.c	Mon Mar  9 08:56:01 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: subr_autoconf.c,v 1.231 2014/08/10 16:44:36 tls Exp $ */
+/* $NetBSD: subr_autoconf.c,v 1.231.2.1 2015/03/09 08:56:01 snj Exp $ */
 
 /*
  * Copyright (c) 1996, 2000 Christopher G. Demetriou
@@ -77,7 +77,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: subr_autoconf.c,v 1.231 2014/08/10 16:44:36 tls Exp $);
+__KERNEL_RCSID(0, $NetBSD: subr_autoconf.c,v 1.231.2.1 2015/03/09 08:56:01 snj Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_ddb.h
@@ -202,6 +202,8 @@ int interrupt_config_threads = 8;
 struct deferred_config_head mountroot_config_queue =
 	TAILQ_HEAD_INITIALIZER(mountroot_config_queue);
 int mountroot_config_threads = 2;
+static lwp_t **mountroot_config_lwpids;
+static size_t mountroot_config_lwpids_size;
 static bool root_is_mounted = false;
 
 static void config_process_deferred(struct deferred_config_head *, device_t);
@@ -481,10 +483,35 @@ config_create_mountrootthreads(void)
 	if (!root_is_mounted)
 		root_is_mounted = true;
 
+	mountroot_config_lwpids_size = sizeof(mountroot_config_lwpids) *
+   mountroot_config_threads;
+	mountroot_config_lwpids = kmem_alloc(mountroot_config_lwpids_size,
+	 KM_NOSLEEP);
+	KASSERT(mountroot_config_lwpids);
 	for (i = 0; i  mountroot_config_threads; i++) {
-		(void)kthread_create(PRI_NONE, 0, NULL,
-		config_mountroot_thread, NULL, NULL, configroot);
+		mountroot_config_lwpids[i] = 0;
+		(void)kthread_create(PRI_NONE, KTHREAD_MUSTJOIN, NULL,
+ config_mountroot_thread, NULL,
+ mountroot_config_lwpids[i],
+ configroot);
+	}
+}
+
+void
+config_finalize_mountroot(void)
+{
+	int i, error;
+
+	for (i = 0; i  mountroot_config_threads; i++) {
+		if (mountroot_config_lwpids[i] == 0)
+			continue;
+
+		error = kthread_join(mountroot_config_lwpids[i]);
+		if (error)
+			printf(%s: thread %x joined with error %d\n,
+			   __func__, i, error);
 	}
+	kmem_free(mountroot_config_lwpids, mountroot_config_lwpids_size);
 }
 
 /*

Index: src/sys/sys/device.h
diff -u src/sys/sys/device.h:1.144 src/sys/sys/device.h:1.144.4.1
--- src/sys/sys/device.h:1.144	Sat Oct 12 16:49:01 2013
+++ src/sys/sys/device.h	Mon Mar  9 08:56:02 2015
@@ -1,4 +1,4 @@
-/* $NetBSD: device.h,v 1.144 2013/10/12 16:49:01 christos Exp $ */
+/* $NetBSD: device.h,v 1.144.4.1 2015/03/09 08:56:02 snj Exp $ */
 
 /*
  * Copyright (c) 1996, 2000 Christopher G. Demetriou
@@ -476,6 +476,7 @@ void	config_create_mountrootthreads(void
 
 int	config_finalize_register(device_t, int (*)(device_t));
 void	config_finalize(void);
+void	config_finalize_mountroot(void);
 
 void	config_twiddle_init(void);
 void	config_twiddle_fn(void *);



CVS commit: [netbsd-7] src

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 09:06:04 UTC 2015

Modified Files:
src/distrib/notes/i386 [netbsd-7]: contents
src/etc/etc.i386 [netbsd-7]: Makefile.inc
src/sys/arch/i386/conf [netbsd-7]: GENERIC
Added Files:
src/sys/arch/i386/conf [netbsd-7]: LEGACY

Log Message:
Pull up following revision(s) (requested by mrg in ticket #578):
distrib/notes/i386/contents: revision 1.28
etc/etc.i386/Makefile.inc: revision 1.68
sys/arch/i386/conf/GENERIC: revision 1.1120
sys/arch/i386/conf/LEGACY: revision 1.1
remove vga@isa and pcdisplay@isa from i386 GENERIC, and create a new
LEGACY kernel that includes them instead.  now radeon@pci is able to
properly claim wsdisplay0 on i386 systems, and radeondrmkms has a good
chance of working.
this fixes PR#49290.


To generate a diff of this commit:
cvs rdiff -u -r1.27 -r1.27.12.1 src/distrib/notes/i386/contents
cvs rdiff -u -r1.67.12.1 -r1.67.12.2 src/etc/etc.i386/Makefile.inc
cvs rdiff -u -r1.1107.2.4 -r1.1107.2.5 src/sys/arch/i386/conf/GENERIC
cvs rdiff -u -r0 -r1.1.2.2 src/sys/arch/i386/conf/LEGACY

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/notes/i386/contents
diff -u src/distrib/notes/i386/contents:1.27 src/distrib/notes/i386/contents:1.27.12.1
--- src/distrib/notes/i386/contents:1.27	Fri Aug 17 20:10:53 2012
+++ src/distrib/notes/i386/contents	Mon Mar  9 09:06:03 2015
@@ -1,4 +1,4 @@
-.\	$NetBSD: contents,v 1.27 2012/08/17 20:10:53 riz Exp $
+.\	$NetBSD: contents,v 1.27.12.1 2015/03/09 09:06:03 snj Exp $
 .\
 .\ Copyright (c) 1999-2005 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -70,6 +70,10 @@ The monolithic kernel which doesn't use 
 .
 The installation kernel.
 .
+.			It Pa netbsd-LEGACY.gz
+.
+The kernel containing support for ISA (VGA and PC Display) display devices.
+.
 .			It Pa netbsd-INSTALL_XEN3PAE_DOMU.gz
 .			It Pa netbsd-INSTALL_XEN3_DOMU.gz
 .			It Pa netbsd-XEN3PAE_DOMU.gz

Index: src/etc/etc.i386/Makefile.inc
diff -u src/etc/etc.i386/Makefile.inc:1.67.12.1 src/etc/etc.i386/Makefile.inc:1.67.12.2
--- src/etc/etc.i386/Makefile.inc:1.67.12.1	Thu Dec  4 19:18:09 2014
+++ src/etc/etc.i386/Makefile.inc	Mon Mar  9 09:06:04 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.67.12.1 2014/12/04 19:18:09 snj Exp $
+#	$NetBSD: Makefile.inc,v 1.67.12.2 2015/03/09 09:06:04 snj Exp $
 #
 #	etc.i386/Makefile.inc -- i386-specific etc Makefile targets
 #
@@ -9,6 +9,7 @@
 KERNEL_SETS=	GENERIC
 KERNEL_SETS+=	MONOLITHIC
 KERNEL_SETS+=	DRMKMS
+KERNEL_SETS+=	LEGACY
 KERNEL_SETS+=	XEN3_DOM0
 KERNEL_SETS+=	XEN3_DOMU
 KERNEL_SETS+=	XEN3PAE_DOM0

Index: src/sys/arch/i386/conf/GENERIC
diff -u src/sys/arch/i386/conf/GENERIC:1.1107.2.4 src/sys/arch/i386/conf/GENERIC:1.1107.2.5
--- src/sys/arch/i386/conf/GENERIC:1.1107.2.4	Tue Jan 20 20:40:50 2015
+++ src/sys/arch/i386/conf/GENERIC	Mon Mar  9 09:06:04 2015
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.1107.2.4 2015/01/20 20:40:50 martin Exp $
+# $NetBSD: GENERIC,v 1.1107.2.5 2015/03/09 09:06:04 snj Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@ include 	arch/i386/conf/std.i386
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		GENERIC-$Revision: 1.1107.2.4 $
+#ident 		GENERIC-$Revision: 1.1107.2.5 $
 
 maxusers	64		# estimated number of users
 
@@ -533,14 +533,15 @@ pms*		at pckbc?		# PS/2 mouse for wsmous
 #options 	PMS_DISABLE_POWERHOOK	# Disable PS/2 reset on resume
 options 	PMS_SYNAPTICS_TOUCHPAD	# Enable support for Synaptics Touchpads
 options 	PMS_ELANTECH_TOUCHPAD	# Enable support for Elantech Touchpads
-vga0		at isa?
+# vga@isa and pcdisplay@isa are disabled; see PR#49290
+#vga0		at isa?
 vga*		at pci? dev ? function ?
-pcdisplay0	at isa?			# CGA, MDA, EGA, HGA
+#pcdisplay0	at isa?			# CGA, MDA, EGA, HGA
 genfb*		at pci? dev ? function ?
 options 	VCONS_DRAW_INTR
 #machfb* 	at pci? dev ? function ? # ATI Mach64 framebuffer driver
 wsdisplay*	at vga? console ?
-wsdisplay*	at pcdisplay? console ?
+#wsdisplay*	at pcdisplay? console ?
 wsdisplay*	at wsemuldisplaydev?
 #wsdisplay*	at machfb? console ?
 wskbd*		at pckbd? console ?

Added files:

Index: src/sys/arch/i386/conf/LEGACY
diff -u /dev/null src/sys/arch/i386/conf/LEGACY:1.1.2.2
--- /dev/null	Mon Mar  9 09:06:04 2015
+++ src/sys/arch/i386/conf/LEGACY	Mon Mar  9 09:06:04 2015
@@ -0,0 +1,14 @@
+#	$NetBSD: LEGACY,v 1.1.2.2 2015/03/09 09:06:04 snj Exp $
+
+# LEGACY kernel -- includes vga@isa and pcdisplay@isa for pre-PCI
+# systems, due to significant pain making them fail to attach when
+# drmkms has not already attached.  see PR#49290 for details.
+
+include arch/i386/conf/GENERIC
+
+vga0		at isa?
+pcdisplay0	at isa?			# CGA, MDA, EGA, HGA
+wsdisplay*	at pcdisplay? console ?
+
+# XXX we could turn off all sorts of other modern features in this
+# configuration, but that is left for future work.



CVS commit: [netbsd-7] src/doc

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 09:23:36 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
tickets 563, 568-570, 574-579


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.222 -r1.1.2.223 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.222 src/doc/CHANGES-7.0:1.1.2.223
--- src/doc/CHANGES-7.0:1.1.2.222	Sat Mar  7 06:36:37 2015
+++ src/doc/CHANGES-7.0	Mon Mar  9 09:23:36 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.222 2015/03/07 06:36:37 snj Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.223 2015/03/09 09:23:36 snj Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -18132,3 +18132,186 @@ usr.sbin/makemandb/makemandb.c			1.26
 	Explicitly deal with end of lists. PR 49708.
 	[skrll, ticket #564]
 
+crypto/external/bsd/openssh/Makefile.inc	patch
+
+	Add -DHAVE_HEADER_AD, to signal a DNSSEC-signed response, so
+	that DNSSEC_signed SSHFPs can be correctly detected.
+	[he, ticket #563]
+	
+sys/arch/sparc64/sparc64/locore.s		1.379, 1.380
+
+	Use panic stack temporarily for calling prom_printf in a trap
+	handler.
+	It seems that openfirmware cannot handle over 4GB pointers, and
+	stack pointers may point to over 4GB since VA layout was
+	rearranged by rev 1.33 of vmparam.h.  Therefore, use panic stack
+	to avoid panicking in OF_write used by prom_printf.
+	[nakayama, ticket #568]
+
+libexec/ld.elf_so/rtld.c			1.175
+
+	HPPA hack for a problem where gdb doesn't see _rtld_debug_state
+	when it's a single bv,n %r0(%rp) instruction.
+	[skrll, ticket #569]
+
+usr.sbin/cpuctl/arch/i386-asm.S			1.4
+usr.sbin/cpuctl/arch/x86_64-asm.S		1.5
+
+	Avoid segfault when running 'cpuctl identify' on newer Intel CPUs.
+	[tnn, ticket #570]
+
+sys/dev/cons.c	1.74
+
+	Fix strange kernel output sequence \n\r observed in serial
+	consoles.  Output '\r' before '\n' in conversion.  PR 36306.
+	[nakayama, ticket #574]
+
+xsrc/external/mit/xf86-video-ati-kms/dist/COPYINGup to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/ChangeLog  up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/INSTALLup to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/Makefile.am up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/Makefile.in up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/README up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/aclocal.m4 up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/compileup to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/config.guess up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/config.h.in up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/config.sub up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/configure  up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/configure.ac up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/depcompup to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/install-sh up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/ltmain.sh  up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/man/Makefile.am up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/man/Makefile.in up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/man/ati.man up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/man/radeon.man up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/missingup to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/Makefile.am up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/Makefile.in up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/ati.c  up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/ati.h  up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/ati_pciids_gen.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/atimodule.c up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/atipciids.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/atipcirename.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/ativersion.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/bicubic_table.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/bicubic_table.py up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/cayman_accel.c up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/cayman_reg.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/cayman_reg_auto.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/cayman_shader.c up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/cayman_shader.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/compat-api.h up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/drmmode_display.c up to 1.1.1.1
+xsrc/external/mit/xf86-video-ati-kms/dist/src/drmmode_display.h up to 1.1.1.1

CVS commit: [netbsd-7] src/crypto/external/bsd/openssh

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 07:46:05 UTC 2015

Modified Files:
src/crypto/external/bsd/openssh [netbsd-7]: Makefile.inc

Log Message:
Apply patch (requested by he in ticket #563):
Add -DHAVE_HEADER_AD, to signal a DNSSEC-signed response, so that
DNSSEC_signed SSHFPs can be correctly detected.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.5.22.1 src/crypto/external/bsd/openssh/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/crypto/external/bsd/openssh/Makefile.inc
diff -u src/crypto/external/bsd/openssh/Makefile.inc:1.5 src/crypto/external/bsd/openssh/Makefile.inc:1.5.22.1
--- src/crypto/external/bsd/openssh/Makefile.inc:1.5	Thu Oct 13 17:23:28 2011
+++ src/crypto/external/bsd/openssh/Makefile.inc	Mon Mar  9 07:46:05 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.5 2011/10/13 17:23:28 plunky Exp $
+#	$NetBSD: Makefile.inc,v 1.5.22.1 2015/03/09 07:46:05 snj Exp $
 
 WARNS?=	4
 
@@ -8,7 +8,14 @@ USE_FORT?= yes	# network client/server
 
 SSHDIST?= ${NETBSDSRCDIR}/crypto/external/bsd/openssh/dist
 
-CPPFLAGS+=-I${SSHDIST} -DHAVE_LOGIN_CAP -DHAVE_MMAP -DHAVE_OPENPTY -DENABLE_PKCS11
+CPPFLAGS+=-I${SSHDIST}
+
+CPPFLAGS+= -DHAVE_HEADER_AD
+CPPFLAGS+= -DHAVE_LOGIN_CAP
+CPPFLAGS+= -DHAVE_MMAP
+CPPFLAGS+= -DHAVE_OPENPTY
+
+CPPFLAGS+=-DENABLE_PKCS11
 .if !defined(NOPIC)
 CPPFLAGS+=-DHAVE_DLOPEN
 .endif



CVS commit: [netbsd-7] src/sys

2015-03-09 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Mon Mar  9 09:29:33 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke/dev [netbsd-7]: pq3sdhc.c
src/sys/dev/sdmmc [netbsd-7]: sdhc.c sdmmc.c

Log Message:
Pull up following revision(s) (requested by nonaka in ticket #577):
sys/arch/powerpc/booke/dev/pq3sdhc.c: revision 1.6
sys/dev/sdmmc/sdhc.c: revision 1.54
sys/dev/sdmmc/sdmmc.c: revision 1.24
eSDHC has no DMA_BOUNDARY in BLOCK_SIZE register.
So clear multi segment DMA transfer support bit.
--
fix to simulate multi-segment dma transfer for pq3sdhc(4).
--
pq3sdhc: Enable DMA transfer.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.5.14.1 src/sys/arch/powerpc/booke/dev/pq3sdhc.c
cvs rdiff -u -r1.44.2.6 -r1.44.2.7 src/sys/dev/sdmmc/sdhc.c
cvs rdiff -u -r1.22.4.1 -r1.22.4.2 src/sys/dev/sdmmc/sdmmc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/dev/pq3sdhc.c
diff -u src/sys/arch/powerpc/booke/dev/pq3sdhc.c:1.5 src/sys/arch/powerpc/booke/dev/pq3sdhc.c:1.5.14.1
--- src/sys/arch/powerpc/booke/dev/pq3sdhc.c:1.5	Thu Jul 26 18:38:10 2012
+++ src/sys/arch/powerpc/booke/dev/pq3sdhc.c	Mon Mar  9 09:29:32 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pq3sdhc.c,v 1.5 2012/07/26 18:38:10 matt Exp $	*/
+/*	$NetBSD: pq3sdhc.c,v 1.5.14.1 2015/03/09 09:29:32 snj Exp $	*/
 /*-
  * Copyright (c) 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -31,7 +31,7 @@
 #define	ESDHC_PRIVATE
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: pq3sdhc.c,v 1.5 2012/07/26 18:38:10 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: pq3sdhc.c,v 1.5.14.1 2015/03/09 09:29:32 snj Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -87,7 +87,7 @@ pq3sdhc_attach(device_t parent, device_t
 	psc-sc_children |= cna-cna_childmask;
 	sc-sc.sc_dmat = cna-cna_dmat;
 	sc-sc.sc_dev = self;
-	//sc-sc.sc_flags |= SDHC_FLAG_USE_DMA;
+	sc-sc.sc_flags |= SDHC_FLAG_USE_DMA;
 	sc-sc.sc_flags |=
 	SDHC_FLAG_HAVE_DVS | SDHC_FLAG_32BIT_ACCESS | SDHC_FLAG_ENHANCED;
 	sc-sc.sc_host = sc-sc_hosts;

Index: src/sys/dev/sdmmc/sdhc.c
diff -u src/sys/dev/sdmmc/sdhc.c:1.44.2.6 src/sys/dev/sdmmc/sdhc.c:1.44.2.7
--- src/sys/dev/sdmmc/sdhc.c:1.44.2.6	Tue Jan 27 08:17:09 2015
+++ src/sys/dev/sdmmc/sdhc.c	Mon Mar  9 09:29:33 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: sdhc.c,v 1.44.2.6 2015/01/27 08:17:09 martin Exp $	*/
+/*	$NetBSD: sdhc.c,v 1.44.2.7 2015/03/09 09:29:33 snj Exp $	*/
 /*	$OpenBSD: sdhc.c,v 1.25 2009/01/13 19:44:20 grange Exp $	*/
 
 /*
@@ -23,7 +23,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sdhc.c,v 1.44.2.6 2015/01/27 08:17:09 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: sdhc.c,v 1.44.2.7 2015/03/09 09:29:33 snj Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_sdmmc.h
@@ -425,7 +425,9 @@ sdhc_host_found(struct sdhc_softc *sc, b
 	if (ISSET(caps, SDHC_HIGH_SPEED_SUPP))
 		saa.saa_caps |= SMC_CAPS_SD_HIGHSPEED;
 	if (ISSET(hp-flags, SHF_USE_DMA)) {
-		saa.saa_caps |= SMC_CAPS_DMA | SMC_CAPS_MULTI_SEG_DMA;
+		saa.saa_caps |= SMC_CAPS_DMA;
+		if (!ISSET(hp-sc-sc_flags, SDHC_FLAG_ENHANCED))
+			saa.saa_caps |= SMC_CAPS_MULTI_SEG_DMA;
 	}
 	if (ISSET(sc-sc_flags, SDHC_FLAG_SINGLE_ONLY))
 		saa.saa_caps |= SMC_CAPS_SINGLE_ONLY;

Index: src/sys/dev/sdmmc/sdmmc.c
diff -u src/sys/dev/sdmmc/sdmmc.c:1.22.4.1 src/sys/dev/sdmmc/sdmmc.c:1.22.4.2
--- src/sys/dev/sdmmc/sdmmc.c:1.22.4.1	Mon Dec  1 11:38:43 2014
+++ src/sys/dev/sdmmc/sdmmc.c	Mon Mar  9 09:29:33 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: sdmmc.c,v 1.22.4.1 2014/12/01 11:38:43 martin Exp $	*/
+/*	$NetBSD: sdmmc.c,v 1.22.4.2 2015/03/09 09:29:33 snj Exp $	*/
 /*	$OpenBSD: sdmmc.c,v 1.18 2009/01/09 10:58:38 jsg Exp $	*/
 
 /*
@@ -49,7 +49,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sdmmc.c,v 1.22.4.1 2014/12/01 11:38:43 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: sdmmc.c,v 1.22.4.2 2015/03/09 09:29:33 snj Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_sdmmc.h
@@ -626,25 +626,31 @@ sdmmc_function_alloc(struct sdmmc_softc 
 		bus_dma_segment_t ds;
 		int rseg, error;
 
-		error = bus_dmamap_create(sc-sc_dmat, SDMMC_SECTOR_SIZE, 1,
-		SDMMC_SECTOR_SIZE, 0, BUS_DMA_WAITOK, sf-bbuf_dmap);
+		error = bus_dmamap_create(sc-sc_dmat, MAXPHYS, 1,
+		MAXPHYS, 0, BUS_DMA_WAITOK, sf-bbuf_dmap);
 		if (error)
 			goto fail1;
-		error = bus_dmamem_alloc(sc-sc_dmat, SDMMC_SECTOR_SIZE,
+		error = bus_dmamem_alloc(sc-sc_dmat, MAXPHYS,
 		PAGE_SIZE, 0, ds, 1, rseg, BUS_DMA_WAITOK);
 		if (error)
 			goto fail2;
-		error = bus_dmamem_map(sc-sc_dmat, ds, 1, SDMMC_SECTOR_SIZE,
+		error = bus_dmamem_map(sc-sc_dmat, ds, 1, MAXPHYS,
 		sf-bbuf, BUS_DMA_WAITOK);
 		if (error)
 			goto fail3;
 		error = bus_dmamap_load(sc-sc_dmat, sf-bbuf_dmap,
-		sf-bbuf, SDMMC_SECTOR_SIZE, NULL,
+		sf-bbuf, MAXPHYS, NULL,
 		BUS_DMA_WAITOK|BUS_DMA_READ|BUS_DMA_WRITE);
+		if (error)
+			goto fail4;
+		error = bus_dmamap_create(sc-sc_dmat, MAXPHYS, 1,
+
Index: src/sys/arch/arm/include/sysarch.h
diff -u src/sys/arch/arm/include/sysarch.h:1.11 src/sys/arch/arm/include/sysarch.h:1.12
--- src/sys/arch/arm/include/sysarch.h:1.11	Thu Jan 16 21:48:41 2014
+++ src/sys/arch/arm/include/sysarch.h	Mon Mar  9 11:03:19 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: sysarch.h,v 1.11 2014/01/16 21:48:41 matt Exp $	*/
+/*	$NetBSD: sysarch.h,v 1.12 2015/03/09 11:03:19 joerg Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -38,13 +38,19 @@
 #include sys/cdefs.h
 
 /*
  * Pickup definition of uintptr_t
  */
+#include machine/ansi.h
 #include sys/stdint.h
 #ifndef _KERNEL
 #include stdbool.h
 #endif
 
+#ifdef	_BSD_SIZE_T_
+typedef	_BSD_SIZE_T_ size_t;
+#undef	_BSD_SIZE_T_
+#endif
+
 /*
  * Architecture specific syscalls (arm)
  */
@@ -38,13 +38,19 @@
 
 /*
- * Pickup definition of uintptr_t
+ * Pickup definition of size_t and uintptr_t
  */



CVS commit: [nick-nhusb] src/sys/dev/usb

2015-03-09 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Tue Mar 10 05:57:15 UTC 2015

Modified Files:
src/sys/dev/usb [nick-nhusb]: uhci.c

Log Message:
usb_quirks.h isn't needed here


To generate a diff of this commit:
cvs rdiff -u -r1.264.4.22 -r1.264.4.23 src/sys/dev/usb/uhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
